@@ -43,37 +43,6 @@ def defdict_to_dict(defdict, finaldict):
             finaldict[k] = v
     return finaldict
 
-def rounded(num, digits_after_decimal = 2):
-    """Rounds numbers properly to specified digits after decimal place
-
-    Args:
-        num (float): Number that is to be rounded
-        digits_after_decimal (int, optional): Number of digits to round to. Defaults to 2.
-
-    Returns:
-        str: A string that is correctly rounded (you know why it's not a float!)
-    """
-    """
-    This needs to be heavily tested!!
-    WARNING: This does not do sig figs yet!
-    """
-
-    # Solution attributed to: https://stackoverflow.com/a/53329223
-
-    if type(num) == str:
-        return num
-    elif type(num) == dict:
-        return num
-    else:
-        from decimal import Decimal, getcontext, ROUND_HALF_UP
-
-        round_context = getcontext()
-        round_context.rounding = ROUND_HALF_UP
-
-        tmp = Decimal(num).quantize(Decimal('1.'+'0'*digits_after_decimal))
-
-        return str(tmp)
-
 def split_body_parts(num_parts,body_parts):
     """Parses individual question parts and splits out titles, and content
 
@@ -219,6 +188,8 @@ def dict_to_md(md_dict, remove_keys = [None,]):
 
     md_string = ""
 
+    md_dict = defdict_to_dict(md_dict,{})
+
     for k,v in md_dict.items():
         if k in remove_keys:
             continue
@@ -282,8 +253,9 @@ def process_multiple_choice(part_name,parsed_question, data_dict):
     else:
         units = ''
 
-    for ans in data_dict['params'][f'{part_name}'].keys():
-        html += f"\t<pl-answer correct= |@ params.{part_name}.{ans}.correct @| > |@ params.{part_name}.{ans}.value @| {units} </pl-answer>\n"
+    for a in data_dict['params'][f'{part_name}'].keys():
+        if 'ans' in a:
+            html += f"\t<pl-answer correct= |@ params.{part_name}.{a}.correct @| > |@ params.{part_name}.{a}.value @| {units} </pl-answer>\n"
 
     html += '</pl-multiple-choice>\n' 
 
@@ -375,7 +347,7 @@ def process_question(input_file, output_path):
         print("File does not exist.")
         raise
 
-    output_path = pathlib.Path(output_path) / input_file.parts[-2]
+    output_path = pathlib.Path(output_path)
 
     # Parse the MD file
     parsed_q = read_md_problem(input_file)
@@ -385,7 +357,11 @@ def process_question(input_file, output_path):
 
     ############### Start Sketchiest Part
     # Run the python code
-    exec(parsed_q['header']['server'].split('# Update the data object with a new dict')[0],globals())
+    try:
+        exec(parsed_q['header']['server'].split('# Update the data object with a new dict')[0],globals())
+    except ModuleNotFoundError:
+        # AWFUL AWFUL hack because of the prairielearn.py file
+        exec(parsed_q['header']['server'].replace('import prairielearn as pl','from . import prairielearn as pl').split('# Update the data object with a new dict')[0],globals())
     ############### End Sketchiest Part
 
     # Write info.json file
